# Generated by Django 4.0.3 on 2022-03-22 09:57

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("ses_sns_tracker", "0003_auto_20220322_0945"),
    ]

    operations = [
        migrations.AlterField(
            model_name="sesmaildelivery",
            name="id",
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID"),
        ),
    ]
